package com.zjsgfa.project.zjsgfa.service;

import java.util.List;
import com.zjsgfa.project.zjsgfa.domain.SjFl;

/**
 * 设计-附录Service接口
 * 
 * @author ruoyi
 * @date 2025-07-25
 */
public interface ISjFlService 
{
    /**
     * 查询设计-附录
     * 
     * @param id 设计-附录主键
     * @return 设计-附录
     */
    public SjFl selectSjFlById(Long id);

    /**
     * 查询设计-附录列表
     * 
     * @param sjFl 设计-附录
     * @return 设计-附录集合
     */
    public List<SjFl> selectSjFlList(SjFl sjFl);

    /**
     * 新增设计-附录
     * 
     * @param sjFl 设计-附录
     * @return 结果
     */
    public int insertSjFl(SjFl sjFl);

    /**
     * 修改设计-附录
     * 
     * @param sjFl 设计-附录
     * @return 结果
     */
    public int updateSjFl(SjFl sjFl);

    /**
     * 批量删除设计-附录
     * 
     * @param ids 需要删除的设计-附录主键集合
     * @return 结果
     */
    public int deleteSjFlByIds(Long[] ids);

    /**
     * 删除设计-附录信息
     * 
     * @param id 设计-附录主键
     * @return 结果
     */
    public int deleteSjFlById(Long id);
}
